==> mediaelement-3.1.2.tgz: package/src/js/languages/ru.js <==
'use strict';

/*!
 * This is a `i18n` language object.
 *
 * Russian
 *
 * @author
 *   Jalios (Twitter: @Jalios)
 *   Sascha Greuel (Twitter: @SoftCreatR)
 *
 * @see core/i18n.js
 */
(function (exports) {
	if (exports.ru === undefined) {
		exports.ru = {
			"mejs.plural-form": 7,

			// renderers/flash.js
			"mejs.install-flash": "Flash player в вашем браузере не установлен или отключен. Пожалуйста включите ваш Flash player или скачайте последнюю версию на https://get.adobe.com/flashplayer/",

			// features/contextmenu.js
			"mejs.fullscreen-off": "Выключить полноэкранный режим",
			"mejs.fullscreen-on": "Перейти в полноэкранный режим",
			"mejs.download-video": "Скачать видео",

			// features/fullscreen.js
			"mejs.fullscreen": "Полноэкранный режим",

			// features/jumpforward.js
			"mejs.time-jump-forward": ["Перейти вперед на %1 секунду", "Перейти вперед на %1 секунды", "Перейти вперед на %1 секунд"],

			// features/loop.js
			"mejs.loop": "Зациклить воспроизведение",

			// features/playpause.js
			"mejs.play": "Воспроизвести",
			"mejs.pause": "Пауза",

			// features/postroll.js
			"mejs.close": "Закрыть",

			// features/progress.js
			"mejs.time-slider": "Слайдер времени",
			"mejs.time-help-text": "Используйте Левую/Правую клавиши со стрелками, чтобы продвинуться на одну секунду, клавиши со стрелками Вверх/Вниз, чтобы продвинуться на десять секунд.",

			// features/skipback.js
			"mejs.time-skip-back": ["Перейти назад на %1 секунду", "Перейти назад на %1 секунды", "Перейти назад на %1 секунд"],

			// features/tracks.js
			"mejs.captions-subtitles": "Титры/Субтитры",
			// "mejs.captions-chapters": "Chapters",
			"mejs.none": "Нет",

			// features/volume.js
			"mejs.mute-toggle": "Без звука",
			"mejs.volume-help-text": "Используйте клавиши со стрелками Вверх/Вниз, чтобы увеличить или уменьшить громкость.",
			"mejs.unmute": "Включить звук",
			"mejs.mute": "Отключить звук",
			"mejs.volume-slider": "Слайдер громкости",

			// core/player.js
			"mejs.video-player": "Видеоплеер",
			"mejs.audio-player": "Аудиоплеер",

			// features/ads.js
			"mejs.ad-skip": "Пропустить рекламу",
			"mejs.ad-skip-info": ["Пропустить через %1 секунду", "Пропустить через %1 секунды", "Пропустить через %1 секунд"],

			// features/sourcechooser.js
			"mejs.source-chooser": "Переключатель источника",

			// features/stop.js
			"mejs.stop": "Остановить",

			//features/speed.js
			"mejs.speed-rate" : "Скорость воспроизведения",

			//features/progress.js
			"mejs.live-broadcast" : "Прямая трансляция",

			// features/tracks.js
			"mejs.afrikaans": "Африканский",
			"mejs.albanian": "Албанский",
			"mejs.arabic": "Арабский",
			"mejs.belarusian": "Белорусский",
			"mejs.bulgarian": "Болгарский",
			"mejs.catalan": "Каталонский",
			"mejs.chinese": "Китайский",
			"mejs.chinese-simplified": "Китайский (упрощенный)",
			"mejs.chinese-traditional": "Chinese (традиционный)",
			"mejs.croatian": "Хорватский",
			"mejs.czech": "Чешский",
			"mejs.danish": "Датский",
			"mejs.dutch": "Голландский",
			"mejs.english": "Английский",
			"mejs.estonian": "Эстонский",
			"mejs.filipino": "Филиппинский",
			"mejs.finnish": "Финский",
			"mejs.french": "Французский",
			"mejs.galician": "Галисийский",
			"mejs.german": "Немецкий",
			"mejs.greek": "Греческий",
			"mejs.haitian-creole": "Гаитянский креольский",
			"mejs.hebrew": "Иврит",
			"mejs.hindi": "Хинди",
			"mejs.hungarian": "Венгерский",
			"mejs.icelandic": "Исландский",
			"mejs.indonesian": "Индонезийский",
			"mejs.irish": "Ирландский",
			"mejs.italian": "Итальянский",
			"mejs.japanese": "Японский",
			"mejs.korean": "Корейский",
			"mejs.latvian": "Латышский",
			"mejs.lithuanian": "Литовский",
			"mejs.macedonian": "Македонский",
			"mejs.malay": "Малайский",
			"mejs.maltese": "Мальтийский",
			"mejs.norwegian": "Норвежский",
			"mejs.persian": "Персидский",
			"mejs.polish": "Польский",
			"mejs.portuguese": "Португальский",
			"mejs.romanian": "Румынский",
			"mejs.russian": "Русский",
			"mejs.serbian": "Сербский",
			"mejs.slovak": "Словацкий",
			"mejs.slovenian": "Словенский",
			"mejs.spanish": "Испанский",
			"mejs.swahili": "Суахили",
			"mejs.swedish": "Шведский",
			"mejs.tagalog": "Тагальский",
			"mejs.thai": "Тайский",
			"mejs.turkish": "Турецкий",
			"mejs.ukrainian": "Украинский",
			"mejs.vietnamese": "Вьетнамский",
			"mejs.welsh": "Валлийский",
			"mejs.yiddish": "Идиш"
		};
	}
})(mejs.i18n);

==> mediaelement-3.1.3.tgz: package/src/js/languages/ru.js <==
'use strict';

/*!
 * This is a `i18n` language object.
 *
 * Russian
 *
 * @author
 *   Jalios (Twitter: @Jalios)
 *   Sascha Greuel (Twitter: @SoftCreatR)
 *
 * @see core/i18n.js
 */
(function (exports) {
	if (exports.ru === undefined) {
		exports.ru = {
			"mejs.plural-form": 7,

			// renderers/flash.js
			"mejs.install-flash": "Flash player в вашем браузере не установлен или отключен. Пожалуйста включите ваш Flash player или скачайте последнюю версию с https://get.adobe.com/flashplayer/",

			// features/contextmenu.js
			"mejs.fullscreen-off": "Выключить полноэкранный режим",
			"mejs.fullscreen-on": "Перейти в полноэкранный режим",
			"mejs.download-video": "Скачать видео",

			// features/fullscreen.js
			"mejs.fullscreen": "Полноэкранный режим",

			// features/jumpforward.js
			"mejs.time-jump-forward": ["Перейти вперед на %1 секунду", "Перейти вперед на %1 секунды", "Перейти вперед на %1 секунд"],

			// features/loop.js
			"mejs.loop": "Зациклить воспроизведение",

			// features/playpause.js
			"mejs.play": "Воспроизвести",
			"mejs.pause": "Пауза",

			// features/postroll.js
			"mejs.close": "Закрыть",

			// features/progress.js
			"mejs.time-slider": "Слайдер времени",
			"mejs.time-help-text": "Используйте Левую/Правую клавиши со стрелками, чтобы продвинуться на одну секунду, клавиши со стрелками Вверх/Вниз, чтобы продвинуться на десять секунд.",

			// features/skipback.js
			"mejs.time-skip-back": ["Перейти назад на %1 секунду", "Перейти назад на %1 секунды", "Перейти назад на %1 секунд"],

			// features/tracks.js
			"mejs.captions-subtitles": "Титры/Субтитры",
			"mejs.captions-chapters": "Главы",
			"mejs.none": "Нет",

			// features/volume.js
			"mejs.volume-help-text": "Используйте клавиши со стрелками Вверх/Вниз, чтобы увеличить или уменьшить громкость.",
			"mejs.unmute": "Включить звук",
			"mejs.mute": "Отключить звук",
			"mejs.volume-slider": "Слайдер громкости",

			// core/player.js
			"mejs.video-player": "Видеоплеер",
			"mejs.audio-player": "Аудиоплеер",

			// features/ads.js
			"mejs.ad-skip": "Пропустить рекламу",
			"mejs.ad-skip-info": ["Пропустить через %1 секунду", "Пропустить через %1 секунды", "Пропустить через %1 секунд"],

			// features/sourcechooser.js
			"mejs.source-chooser": "Переключатель источника",

			// features/stop.js
			"mejs.stop": "Остановить",

			//features/speed.js
			"mejs.speed-rate" : "Скорость воспроизведения",

			//features/progress.js
			"mejs.live-broadcast" : "Прямая трансляция",

			// features/tracks.js
			"mejs.afrikaans": "Африканский",
			"mejs.albanian": "Албанский",
			"mejs.arabic": "Арабский",
			"mejs.belarusian": "Белорусский",
			"mejs.bulgarian": "Болгарский",
			"mejs.catalan": "Каталонский",
			"mejs.chinese": "Китайский",
			"mejs.chinese-simplified": "Китайский (упрощенный)",
			"mejs.chinese-traditional": "Chinese (традиционный)",
			"mejs.croatian": "Хорватский",
			"mejs.czech": "Чешский",
			"mejs.danish": "Датский",
			"mejs.dutch": "Голландский",
			"mejs.english": "Английский",
			"mejs.estonian": "Эстонский",
			"mejs.filipino": "Филиппинский",
			"mejs.finnish": "Финский",
			"mejs.french": "Французский",
			"mejs.galician": "Галисийский",
			"mejs.german": "Немецкий",
			"mejs.greek": "Греческий",
			"mejs.haitian-creole": "Гаитянский креольский",
			"mejs.hebrew": "Иврит",
			"mejs.hindi": "Хинди",
			"mejs.hungarian": "Венгерский",
			"mejs.icelandic": "Исландский",
			"mejs.indonesian": "Индонезийский",
			"mejs.irish": "Ирландский",
			"mejs.italian": "Итальянский",
			"mejs.japanese": "Японский",
			"mejs.korean": "Корейский",
			"mejs.latvian": "Латышский",
			"mejs.lithuanian": "Литовский",
			"mejs.macedonian": "Македонский",
			"mejs.malay": "Малайский",
			"mejs.maltese": "Мальтийский",
			"mejs.norwegian": "Норвежский",
			"mejs.persian": "Персидский",
			"mejs.polish": "Польский",
			"mejs.portuguese": "Португальский",
			"mejs.romanian": "Румынский",
			"mejs.russian": "Русский",
			"mejs.serbian": "Сербский",
			"mejs.slovak": "Словацкий",
			"mejs.slovenian": "Словенский",
			"mejs.spanish": "Испанский",
			"mejs.swahili": "Суахили",
			"mejs.swedish": "Шведский",
			"mejs.tagalog": "Тагальский",
			"mejs.thai": "Тайский",
			"mejs.turkish": "Турецкий",
			"mejs.ukrainian": "Украинский",
			"mejs.vietnamese": "Вьетнамский",
			"mejs.welsh": "Валлийский",
			"mejs.yiddish": "Идиш"
		};
	}
})(mejs.i18n);
